@@ -43,7 +43,7 @@
 #define UI_FILE PACKAGE_DATA_DIR "/ui/anjuta-project-manager.xml"
 #define PREFS_GLADE PACKAGE_DATA_DIR "/glade/anjuta-project-manager-plugin.ui"
 #define ICON_FILE "anjuta-project-manager-plugin-48.png"
-#define DEFAULT_PROFILE "file://"PACKAGE_DATA_DIR "/profiles/default.profile"
+#define DEFAULT_PROFILE "default.profile"
 #define PROJECT_PROFILE_NAME "project"
 
 #define INT_TO_GBOOLEAN(i) ((i) ? TRUE : FALSE)
@@ -379,7 +379,7 @@ get_plugin_parent_window (ProjectManagerPlugin *plugin)
 }
 
 gboolean
-change_project_backend (ProjectManagerPlugin *plugin, AnjutaPluginDescription *backend)
+change_project_backend (ProjectManagerPlugin *plugin, AnjutaPluginHandle *backend)
 {
 	gchar *content;
 	gsize length;
@@ -421,9 +421,11 @@ change_project_backend (ProjectManagerPlugin *plugin, AnjutaPluginDescription *b
 			GFileOutputStream *stream;
 			gchar *name = NULL;
 			gchar *plugin_id = NULL;
+			AnjutaPluginDescription *desc;
 
-			anjuta_plugin_description_get_string (backend, "Anjuta Plugin", "Name", &name);
-			anjuta_plugin_description_get_string (backend, "Anjuta Plugin", "Location", &plugin_id);
+			desc = anjuta_plugin_handle_get_description (backend);
+			anjuta_plugin_description_get_string (desc, "Anjuta Plugin", "Name", &name);
+			anjuta_plugin_description_get_string (desc, "Anjuta Plugin", "Location", &plugin_id);
 
 			str = g_string_new (NULL);
 			g_string_printf (str, "<plugin name= \"%s\"\n"
@@ -1449,15 +1451,9 @@ project_manager_unload_gbf (ProjectManagerPlugin *pm_plugin)
 }
 
 static void
-on_profile_scoped (AnjutaProfileManager *profile_manager,
-				   AnjutaProfile *profile, ProjectManagerPlugin *plugin)
+on_profile_scoped (AnjutaProfile *profile, ProjectManagerPlugin *plugin)
 {
 	gchar *session_dir;
-	DEBUG_PRINT ("Profile scoped: %s", anjuta_profile_get_name (profile));
-	if (strcmp (anjuta_profile_get_name (profile), PROJECT_PROFILE_NAME) != 0)
-		return;
-
-	DEBUG_PRINT ("%s", "Project profile loaded; Restoring project session");
 
 	/* Load gbf project */
 	project_manager_load_gbf (plugin);
@@ -1482,14 +1478,8 @@ on_profile_scoped (AnjutaProfileManager *profile_manager,
 }
 
 static void
-on_profile_descoped (AnjutaProfileManager *profile_manager,
-					 AnjutaProfile *profile, ProjectManagerPlugin *plugin)
+on_profile_descoped (AnjutaProfile *profile, ProjectManagerPlugin *plugin)
 {
-	DEBUG_PRINT ("Profile descoped: %s", anjuta_profile_get_name (profile));
-
-	if (strcmp (anjuta_profile_get_name (profile), PROJECT_PROFILE_NAME) != 0)
-		return;
-
 	DEBUG_PRINT ("%s", "Project profile descoped; Saving project session");
 
 	/* Save current project session */
@@ -1520,7 +1510,8 @@ project_manager_plugin_close (ProjectManagerPlugin *plugin)
 	/* Remove project profile */
 	profile_manager =
 		anjuta_shell_get_profile_manager (ANJUTA_PLUGIN (plugin)->shell, NULL);
-	anjuta_profile_manager_pop (profile_manager, PROJECT_PROFILE_NAME, &error);
+	anjuta_profile_manager_pop (profile_manager, plugin->profile, &error);
+	plugin->profile = NULL;
 	if (error)
 	{
 		anjuta_util_dialog_error (get_plugin_parent_window (plugin),
@@ -1533,7 +1524,6 @@ project_manager_plugin_close (ProjectManagerPlugin *plugin)
 static gboolean
 project_manager_plugin_activate_plugin (AnjutaPlugin *plugin)
 {
-	AnjutaProfileManager *profile_manager;
 	GtkWidget *scrolled_window;
 	GtkWidget *view;
 	static gboolean initialized = FALSE;
@@ -1639,20 +1629,14 @@ project_manager_plugin_activate_plugin (AnjutaPlugin *plugin)
 					  G_CALLBACK (on_session_save), plugin);
 	g_signal_connect (G_OBJECT (plugin->shell), "load_session",
 					  G_CALLBACK (on_session_load), plugin);
-	profile_manager = anjuta_shell_get_profile_manager (plugin->shell, NULL);
 
-	/* Connect to profile scoping */
-	g_signal_connect (profile_manager, "profile-scoped",
-					  G_CALLBACK (on_profile_scoped), plugin);
-	g_signal_connect (profile_manager, "profile-descoped",
-					  G_CALLBACK (on_profile_descoped), plugin);
+
 	return TRUE;
 }
 
 static gboolean
 project_manager_plugin_deactivate_plugin (AnjutaPlugin *plugin)
 {
-	AnjutaProfileManager *profile_manager;
 	ProjectManagerPlugin *pm_plugin;
 	pm_plugin = ANJUTA_PLUGIN_PROJECT_MANAGER (plugin);
 
@@ -1666,8 +1650,6 @@ project_manager_plugin_deactivate_plugin (AnjutaPlugin *plugin)
 	if (pm_plugin->project_root_uri)
 		project_manager_plugin_close (pm_plugin);
 
-	profile_manager = anjuta_shell_get_profile_manager (plugin->shell, NULL);
-
 	/* Disconnect signals */
 	g_signal_handlers_disconnect_by_func (G_OBJECT (plugin->shell),
 										  G_CALLBACK (on_session_save),
@@ -1675,12 +1657,15 @@ project_manager_plugin_deactivate_plugin (AnjutaPlugin *plugin)
 	g_signal_handlers_disconnect_by_func (G_OBJECT (plugin->shell),
 										  G_CALLBACK (on_session_load),
 										  plugin);
-	g_signal_handlers_disconnect_by_func (G_OBJECT (profile_manager),
-										  G_CALLBACK (on_profile_descoped),
-										  plugin);
-	g_signal_handlers_disconnect_by_func (G_OBJECT (profile_manager),
-										  G_CALLBACK (on_profile_scoped),
-										  plugin);
+	if (pm_plugin->profile != NULL)
+	{
+		g_signal_handlers_disconnect_by_func (G_OBJECT (pm_plugin->profile),
+		                                      G_CALLBACK (on_profile_descoped),
+		                                      plugin);
+		g_signal_handlers_disconnect_by_func (G_OBJECT (pm_plugin->profile),
+		                                      G_CALLBACK (on_profile_scoped),
+		                                      plugin);
+	}
 	/* Remove watches */
 	anjuta_plugin_remove_watch (plugin, pm_plugin->fm_watch_id, TRUE);
 	anjuta_plugin_remove_watch (plugin, pm_plugin->editor_watch_id, TRUE);
@@ -1735,6 +1720,7 @@ project_manager_plugin_instance_init (GObject *obj)
 	plugin->session_by_me = FALSE;
 	plugin->close_project_idle = -1;
 	plugin->shortcuts = NULL;
+	plugin->profile = NULL;
 }
 
 static void
@@ -2306,9 +2292,8 @@ ifile_open (IAnjutaFile *ifile, GFile* file, GError **e)
 	AnjutaProfileManager *profile_manager;
 	AnjutaPluginManager *plugin_manager;
 	AnjutaStatus *status;
-	gchar *session_profile_path, *profile_name;
+	gchar *session_profile_path;
 	GFile *session_profile;
-	GFile *default_profile;
 	GFile *project_root;
 	GFile *tmp;
 	ProjectManagerPlugin *plugin;
@@ -2339,20 +2324,10 @@ ifile_open (IAnjutaFile *ifile, GFile* file, GError **e)
 	/* Prepare profile */
 	profile = anjuta_profile_new (PROJECT_PROFILE_NAME, plugin_manager);
 
-	/* System default profile */
-	default_profile = g_file_new_for_uri (DEFAULT_PROFILE);
-	anjuta_profile_add_plugins_from_xml (profile, default_profile,
-										 TRUE, &error);
-	profile_name = g_file_get_basename (default_profile);
-	g_object_unref (default_profile);
-	if (error)
-	{
-		g_propagate_error (e, error);
-		g_free (profile_name);
-		g_object_unref (profile);
-
-		return;
-	}
+	/* Connect to profile scoping */
+	g_signal_connect (profile, "scoped", G_CALLBACK (on_profile_scoped), plugin);
+	g_signal_connect (profile, "descoped", G_CALLBACK (on_profile_descoped), plugin);
+	plugin->profile = profile;
 
 	/* Project default profile */
 	anjuta_profile_add_plugins_from_xml (profile, file, TRUE, &error);
@@ -2360,7 +2335,6 @@ ifile_open (IAnjutaFile *ifile, GFile* file, GError **e)
 	{
 		g_propagate_error (e, error);
 
-		g_free (profile_name);
 		g_object_unref (profile);
 
 		return;
@@ -2369,9 +2343,8 @@ ifile_open (IAnjutaFile *ifile, GFile* file, GError **e)
 	/* Project session profile */
 	project_root = g_file_get_parent (file);
 	tmp = g_file_get_child (project_root, ".anjuta");
-	session_profile = g_file_get_child (tmp, profile_name);
+	session_profile = g_file_get_child (tmp, DEFAULT_PROFILE);
 	g_object_unref (tmp);
-	g_free (profile_name);
 
 	session_profile_path = g_file_get_path (session_profile);
 	DEBUG_PRINT ("Loading project session profile: %s", session_profile_path);
