@@ -46,6 +46,7 @@
 #include <libanjuta/interfaces/ianjuta-editor-glade-signal.h>
 #include <libanjuta/interfaces/ianjuta-language-provider.h>
 #include <libanjuta/interfaces/ianjuta-provider.h>
+#include <libanjuta/interfaces/ianjuta-symbol-manager.h>
 
 #include <gtksourceview/gtksource.h>
 
@@ -926,6 +927,10 @@ sourceview_instance_init(Sourceview* sv)
 	sv->priv = G_TYPE_INSTANCE_GET_PRIVATE (sv,
 	                                        ANJUTA_TYPE_SOURCEVIEW,
 	                                        SourceviewPrivate);
+
+	/* set properties */
+	g_object_set (G_OBJECT (sv), "orientation", GTK_ORIENTATION_VERTICAL,
+	              NULL);
 }
 
 static void
@@ -1178,7 +1183,7 @@ static void ieditor_goto_position(IAnjutaEditor *editor, IAnjutaIterable* icell,
 	sourceview_cell_get_iter (cell, &iter);
 	gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (sv->priv->document), &iter);
 	gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (sv->priv->view),
-	                                    gtk_text_buffer_get_insert (sv->priv->document));
+	                                    gtk_text_buffer_get_insert (GTK_TEXT_BUFFER (sv->priv->document)));
 }
 
 /* Return a newly allocated pointer containing the whole text */
@@ -1549,6 +1554,11 @@ static void idocument_end_undo_action (IAnjutaDocument *editor, GError **e)
 	gtk_text_buffer_end_user_action (GTK_TEXT_BUFFER(sv->priv->document));
 }
 
+static void
+update_symbols(IAnjutaDocument* edit)
+{
+	g_signal_emit_by_name (G_OBJECT (IANJUTA_EDITOR(edit)), "code-changed", NULL, NULL);
+}
 
 static void
 idocument_undo(IAnjutaDocument* edit, GError** ee)
@@ -1564,6 +1574,7 @@ idocument_undo(IAnjutaDocument* edit, GError** ee)
 	
 	anjuta_view_scroll_to_cursor(sv->priv->view);
 	g_signal_emit_by_name(G_OBJECT(sv), "update_ui", sv);
+	update_symbols(edit);
 }
 
 static void
@@ -1574,6 +1585,7 @@ idocument_redo(IAnjutaDocument* edit, GError** ee)
 		gtk_source_buffer_redo(GTK_SOURCE_BUFFER(sv->priv->document));
 	anjuta_view_scroll_to_cursor(sv->priv->view);
 	g_signal_emit_by_name(G_OBJECT(sv), "update_ui", sv);
+	update_symbols(edit);
 }
 
 /* Grab focus */
@@ -1597,6 +1609,7 @@ idocument_cut(IAnjutaDocument* edit, GError** ee)
 	g_signal_handlers_block_by_func (sv->priv->document, on_insert_text, sv);
 	anjuta_view_cut_clipboard(sv->priv->view);
 	g_signal_handlers_unblock_by_func (sv->priv->document, on_insert_text, sv);
+	update_symbols(edit);
 }
 
 static void
@@ -1615,6 +1628,7 @@ idocument_paste(IAnjutaDocument* edit, GError** ee)
 	g_signal_handlers_block_by_func (sv->priv->document, on_insert_text, sv);
 	anjuta_view_paste_clipboard(sv->priv->view);
 	g_signal_handlers_unblock_by_func (sv->priv->document, on_insert_text, sv);
+	update_symbols(edit);
 }
 
 static void
@@ -2599,7 +2613,7 @@ iglade_iface_init(IAnjutaEditorGladeSignalIface* iface)
 	/* only signals */
 }
 
-ANJUTA_TYPE_BEGIN(Sourceview, sourceview, GTK_TYPE_VBOX);
+ANJUTA_TYPE_BEGIN(Sourceview, sourceview, GTK_TYPE_BOX);
 ANJUTA_TYPE_ADD_INTERFACE(idocument, IANJUTA_TYPE_DOCUMENT);
 ANJUTA_TYPE_ADD_INTERFACE(ifile, IANJUTA_TYPE_FILE);
 ANJUTA_TYPE_ADD_INTERFACE(isavable, IANJUTA_TYPE_FILE_SAVABLE);
