@@ -39,15 +39,18 @@
 #define ANJUTA_SESSION_SKIP_LAST "session-skip-last"
 #define ANJUTA_SESSION_SKIP_LAST_FILES "session-skip-last-files"
 
-#define DEFAULT_PROFILE "file://"PACKAGE_DATA_DIR"/profiles/default.profile"
+#define PROFILE_DIRECTORY "file://"PACKAGE_DATA_DIR"/profiles"
 #define USER_PROFILE_NAME "user"
 
 #define ANJUTA_PIXMAP_SPLASH_SCREEN       "anjuta_splash.png"
 
-#define ANJUTA_GEOMETRY_HINT "-g="
-#define ANJUTA_NO_SPLASH_HINT "-s"
-#define ANJUTA_NO_SESSION_HINT "-n"
-#define ANJUTA_NO_FILES_HINT "-f"
+#define ANJUTA_GEOMETRY_HINT ";g="
+#define ANJUTA_PROFILE_HINT ";P="
+#define ANJUTA_NO_SPLASH_HINT ";s"
+#define ANJUTA_NO_SESSION_HINT ";n"
+#define ANJUTA_NO_FILES_HINT ";f"
+
+static gchar DEFAULT_PROFILE[] = "default.profile";
 
 G_DEFINE_TYPE (AnjutaApplication, anjuta_application, GTK_TYPE_APPLICATION)
 
@@ -57,6 +60,7 @@ struct _AnjutaApplicationPrivate {
 	gboolean no_files;
 	gboolean no_session;
 	gchar *geometry;
+	gchar *profile;
 };
 
 static gboolean
@@ -114,7 +118,7 @@ on_anjuta_delete_event (AnjutaWindow *win, GdkEvent *event, gpointer user_data)
 		}
 	}
 
-	/* Close the profile manager which will emit "profile-descoped" and release
+	/* Close the profile manager which will emit "descoped" and release
 	 * all previous profiles. */
 	anjuta_profile_manager_close (profile_manager);
 
@@ -135,17 +139,12 @@ on_anjuta_delete_event (AnjutaWindow *win, GdkEvent *event, gpointer user_data)
 }
 
 static void
-on_profile_scoped (AnjutaProfileManager *profile_manager,
-				   AnjutaProfile *profile, AnjutaWindow *win)
+on_profile_scoped (AnjutaProfile *profile, AnjutaWindow *win)
 {
 	gchar *session_dir;
 	static gboolean first_time = TRUE;
 	AnjutaSession *session;
 
-	DEBUG_PRINT ("Profile scoped: %s", anjuta_profile_get_name (profile));
-	if (strcmp (anjuta_profile_get_name (profile), USER_PROFILE_NAME) != 0)
-		return;
-
 	DEBUG_PRINT ("%s", "User profile loaded; Restoring user session");
 
 	/* If profile scoped to "user", restore user session */
@@ -182,15 +181,10 @@ on_profile_scoped (AnjutaProfileManager *profile_manager,
 }
 
 static void
-on_profile_descoped (AnjutaProfileManager *profile_manager,
-					 AnjutaProfile *profile, AnjutaWindow *win)
+on_profile_descoped (AnjutaProfile *profile, AnjutaWindow *win)
 {
 	gchar *session_dir;
 
-	DEBUG_PRINT ("Profile descoped: %s", anjuta_profile_get_name (profile));
-	if (strcmp (anjuta_profile_get_name (profile), USER_PROFILE_NAME) != 0)
-		return;
-
 	DEBUG_PRINT ("%s", "User profile descoped; Saving user session");
 
 	/* If profile descoped from is "user", save user session */
@@ -207,7 +201,8 @@ static gchar *
 create_anjuta_application_hint (const gchar *geometry,
                                 gboolean no_splash,
                                 gboolean no_session,
-                                gboolean no_files)
+                                gboolean no_files,
+                                const gchar *profile)
 {
 	GString *hint;
 
@@ -220,7 +215,12 @@ create_anjuta_application_hint (const gchar *geometry,
 	if (no_splash) g_string_append (hint,ANJUTA_NO_SPLASH_HINT);
 	if (no_session) g_string_append (hint,ANJUTA_NO_SESSION_HINT);
 	if (no_files) g_string_append (hint,ANJUTA_NO_FILES_HINT);
-	g_string_append_c(hint, '-');
+	if (profile != NULL)
+	{
+		g_string_append (hint, ANJUTA_PROFILE_HINT);
+		g_string_append_uri_escaped (hint, profile, NULL, FALSE);
+	}
+	g_string_append_c(hint, ';');
 
 	return g_string_free (hint, FALSE);
 }
@@ -231,13 +231,14 @@ anjuta_application_parse_hint (AnjutaApplication *app,
                                const gchar* hint)
 {
 	const gchar *geometry;
+	const gchar *profile;
 
 	g_free (app->priv->geometry);
 	app->priv->geometry = NULL;
 	geometry = strstr(hint, ANJUTA_GEOMETRY_HINT);
 	if (geometry != NULL)
 	{
-		const gchar *end = strstr(geometry + 1, "-");
+		const gchar *end = strstr(geometry + 1, ";");
 
 		if (end != NULL)
 		{
@@ -245,9 +246,22 @@ anjuta_application_parse_hint (AnjutaApplication *app,
 			app->priv->geometry = g_strndup (geometry, end - geometry);
 		}
 	}
-	app->priv->no_splash = strstr(hint, ANJUTA_NO_SPLASH_HINT "-") != NULL ? TRUE : FALSE;
-	app->priv->no_session = strstr(hint, ANJUTA_NO_SESSION_HINT "-") != NULL ? TRUE : FALSE;
-	app->priv->no_files = strstr(hint, ANJUTA_NO_FILES_HINT "-") != NULL ? TRUE : FALSE;
+	app->priv->no_splash = strstr(hint, ANJUTA_NO_SPLASH_HINT ";") != NULL ? TRUE : FALSE;
+	app->priv->no_session = strstr(hint, ANJUTA_NO_SESSION_HINT ";") != NULL ? TRUE : FALSE;
+	app->priv->no_files = strstr(hint, ANJUTA_NO_FILES_HINT ";") != NULL ? TRUE : FALSE;
+	g_free (app->priv->profile);
+	app->priv->profile = NULL;
+	profile = strstr(hint, ANJUTA_PROFILE_HINT);
+	if (profile != NULL)
+	{
+		const gchar *end = strstr(profile + 1, ";");
+
+		if (end != NULL)
+		{
+			profile += strlen (ANJUTA_PROFILE_HINT);
+			app->priv->profile = g_uri_unescape_segment (profile, end, NULL);
+		}
+	}
 }
 
 static void
@@ -276,6 +290,7 @@ anjuta_application_local_command_line (GApplication *application,
 	gboolean no_files = FALSE;
 	gboolean version = FALSE;
 	gchar *geometry = NULL;
+	gchar *profile = NULL;
 	gchar **filenames = NULL;
 
 	const GOptionEntry anjuta_options[] = {
@@ -323,6 +338,12 @@ anjuta_application_local_command_line (GApplication *application,
 			N_("Display program version"),
 			NULL
 		},
+		{
+			"profile", 'P', 0, G_OPTION_ARG_STRING,
+			&profile,
+			N_("Specify another profile"),
+			N_("profile file")
+		},
 		{
 			G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY,
 			&filenames,
@@ -369,6 +390,12 @@ anjuta_application_local_command_line (GApplication *application,
 		return TRUE;
 	}
 
+	/* Set application prefix */
+	if (profile != NULL)
+	{
+		anjuta_util_set_anjuta_prefix (profile);
+	}
+
 	/* Register application */
 	if (no_client) g_application_set_flags (application, G_APPLICATION_NON_UNIQUE | g_application_get_flags (application));
 	g_application_register (G_APPLICATION (application), NULL, NULL);
@@ -388,7 +415,7 @@ anjuta_application_local_command_line (GApplication *application,
 	}
 
 	/* Create hint string */
-	hint = create_anjuta_application_hint (geometry, no_splash, no_session, no_files);
+	hint = create_anjuta_application_hint (geometry, no_splash, no_session, no_files, profile);
 
 	/* Open files */
 	g_application_open (application, (GFile **)files->pdata, files->len, hint);
@@ -550,9 +577,10 @@ anjuta_application_create_window (AnjutaApplication *app)
 	AnjutaWindow *win;
 	AnjutaStatus *status;
 	AnjutaProfile *profile;
+	gchar *profile_filename;
+	GFile *profile_directory;
 	GFile *session_profile;
 	gchar *remembered_plugins;
-	gchar *profile_name = NULL;
 	GError *error = NULL;
 
 	/* Initialize application */
@@ -598,22 +626,34 @@ anjuta_application_create_window (AnjutaApplication *app)
 													  remembered_plugins);
 	g_free (remembered_plugins);
 
-	/* Prepare profile */
-	profile = anjuta_profile_new (USER_PROFILE_NAME, plugin_manager);
-	session_profile = g_file_new_for_uri (DEFAULT_PROFILE);
+	/* Prepare system profile */
+	profile = anjuta_profile_new (ANJUTA_SYSTEM_PROFILE_NAME, plugin_manager);
+	profile_filename = app->priv->profile == NULL ? DEFAULT_PROFILE : g_strconcat(app->priv->profile, ".profile", NULL);
+	profile_directory = g_file_new_for_uri (PROFILE_DIRECTORY);
+	session_profile = g_file_get_child(profile_directory, profile_filename);
+	g_object_unref(profile_directory);
 	anjuta_profile_add_plugins_from_xml (profile, session_profile,
 										 TRUE, &error);
 	if (error)
+	{
+		anjuta_util_dialog_error (GTK_WINDOW (win), _("Invalid profile %s: %s"), g_file_get_path (session_profile), error->message);
+
+		g_error_free (error);
+		error = NULL;
+	}
+	g_object_unref (session_profile);
+	anjuta_profile_manager_freeze (profile_manager);
+	anjuta_profile_manager_push (profile_manager, profile, &error);
+	if (error)
 	{
 		anjuta_util_dialog_error (GTK_WINDOW (win), "%s", error->message);
 		g_error_free (error);
 		error = NULL;
 	}
-	g_object_unref (session_profile);
 
-	/* Load user session profile */
-	profile_name = g_path_get_basename (DEFAULT_PROFILE);
-	session_profile = anjuta_util_get_user_cache_file (profile_name, NULL);
+	/* Prepare user profile */
+	profile = anjuta_profile_new (USER_PROFILE_NAME, plugin_manager);
+	session_profile = anjuta_util_get_user_cache_file (profile_filename, NULL);
 	if (g_file_query_exists (session_profile, NULL))
 	{
 		anjuta_profile_add_plugins_from_xml (profile, session_profile,
@@ -627,10 +667,9 @@ anjuta_application_create_window (AnjutaApplication *app)
 	}
 	anjuta_profile_set_sync_file (profile, session_profile);
 	g_object_unref (session_profile);
-	g_free (profile_name);
+	if (profile_filename != DEFAULT_PROFILE) g_free (profile_filename);
 
 	/* Load profile */
-	anjuta_profile_manager_freeze (profile_manager);
 	anjuta_profile_manager_push (profile_manager, profile, &error);
 	if (error)
 	{
@@ -640,8 +679,7 @@ anjuta_application_create_window (AnjutaApplication *app)
 	}
 
 	/* Prepare for session save and load on profile change */
-	g_signal_connect (profile_manager, "profile-scoped",
-					  G_CALLBACK (on_profile_scoped), win);
+	g_signal_connect (profile, "scoped", G_CALLBACK (on_profile_scoped), win);
 	anjuta_profile_manager_thaw (profile_manager, &error);
 
 	if (error)
@@ -650,8 +688,7 @@ anjuta_application_create_window (AnjutaApplication *app)
 		g_error_free (error);
 		error = NULL;
 	}
-	g_signal_connect (profile_manager, "profile-descoped",
-					  G_CALLBACK (on_profile_descoped), win);
+	g_signal_connect (profile, "descoped", G_CALLBACK (on_profile_descoped), win);
 
 	anjuta_status_progress_tick (status, NULL, _("Loaded Session…"));
 	anjuta_status_disable_splash (status, TRUE);
